(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('@angular/core'), require('@angular/common/http')) :
    typeof define === 'function' && define.amd ? define('clash-bot-service-api', ['exports', '@angular/core', '@angular/common/http'], factory) :
    (global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory(global["clash-bot-service-api"] = {}, global.ng.core, global.ng.common.http));
})(this, (function (exports, i0, i1) { 'use strict';

    function _interopNamespace(e) {
        if (e && e.__esModule) return e;
        var n = Object.create(null);
        if (e) {
            Object.keys(e).forEach(function (k) {
                if (k !== 'default') {
                    var d = Object.getOwnPropertyDescriptor(e, k);
                    Object.defineProperty(n, k, d.get ? d : {
                        enumerable: true,
                        get: function () { return e[k]; }
                    });
                }
            });
        }
        n["default"] = e;
        return Object.freeze(n);
    }

    var i0__namespace = /*#__PURE__*/_interopNamespace(i0);
    var i1__namespace = /*#__PURE__*/_interopNamespace(i1);

    /**
     * Custom HttpParameterCodec
     * Workaround for https://github.com/angular/angular/issues/18261
     */
    var CustomHttpParameterCodec = /** @class */ (function () {
        function CustomHttpParameterCodec() {
        }
        CustomHttpParameterCodec.prototype.encodeKey = function (k) {
            return encodeURIComponent(k);
        };
        CustomHttpParameterCodec.prototype.encodeValue = function (v) {
            return encodeURIComponent(v);
        };
        CustomHttpParameterCodec.prototype.decodeKey = function (k) {
            return decodeURIComponent(k);
        };
        CustomHttpParameterCodec.prototype.decodeValue = function (v) {
            return decodeURIComponent(v);
        };
        return CustomHttpParameterCodec;
    }());

    var BASE_PATH = new i0.InjectionToken('basePath');
    var COLLECTION_FORMATS = {
        'csv': ',',
        'tsv': '   ',
        'ssv': ' ',
        'pipes': '|'
    };

    var Configuration = /** @class */ (function () {
        function Configuration(configurationParameters) {
            if (configurationParameters === void 0) { configurationParameters = {}; }
            this.apiKeys = configurationParameters.apiKeys;
            this.username = configurationParameters.username;
            this.password = configurationParameters.password;
            this.accessToken = configurationParameters.accessToken;
            this.basePath = configurationParameters.basePath;
            this.withCredentials = configurationParameters.withCredentials;
            this.encoder = configurationParameters.encoder;
            if (configurationParameters.credentials) {
                this.credentials = configurationParameters.credentials;
            }
            else {
                this.credentials = {};
            }
        }
        /**
         * Select the correct content-type to use for a request.
         * Uses {@link Configuration#isJsonMime} to determine the correct content-type.
         * If no content type is found return the first found type if the contentTypes is not empty
         * @param contentTypes - the array of content types that are available for selection
         * @returns the selected content-type or <code>undefined</code> if no selection could be made.
         */
        Configuration.prototype.selectHeaderContentType = function (contentTypes) {
            var _this = this;
            if (contentTypes.length === 0) {
                return undefined;
            }
            var type = contentTypes.find(function (x) { return _this.isJsonMime(x); });
            if (type === undefined) {
                return contentTypes[0];
            }
            return type;
        };
        /**
         * Select the correct accept content-type to use for a request.
         * Uses {@link Configuration#isJsonMime} to determine the correct accept content-type.
         * If no content type is found return the first found type if the contentTypes is not empty
         * @param accepts - the array of content types that are available for selection.
         * @returns the selected content-type or <code>undefined</code> if no selection could be made.
         */
        Configuration.prototype.selectHeaderAccept = function (accepts) {
            var _this = this;
            if (accepts.length === 0) {
                return undefined;
            }
            var type = accepts.find(function (x) { return _this.isJsonMime(x); });
            if (type === undefined) {
                return accepts[0];
            }
            return type;
        };
        /**
         * Check if the given MIME is a JSON MIME.
         * JSON MIME examples:
         *   application/json
         *   application/json; charset=UTF8
         *   APPLICATION/JSON
         *   application/vnd.company+json
         * @param mime - MIME (Multipurpose Internet Mail Extensions)
         * @return True if the given MIME is JSON, false otherwise.
         */
        Configuration.prototype.isJsonMime = function (mime) {
            var jsonMime = new RegExp('^(application\/json|[^;/ \t]+\/[^;/ \t]+[+]json)[ \t]*(;.*)?$', 'i');
            return mime !== null && (jsonMime.test(mime) || mime.toLowerCase() === 'application/json-patch+json');
        };
        Configuration.prototype.lookupCredential = function (key) {
            var value = this.credentials[key];
            return typeof value === 'function'
                ? value()
                : value;
        };
        return Configuration;
    }());

    /**
     * clash-bot-webapp-service
     * Clash Bot Webapp Service to support League of Legends Clash tournament scheduling with Discord.
     *
     * The version of the OpenAPI document: 1.1.0
     * Contact: rixxroid@gmail.com
     *
     * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
     * https://openapi-generator.tech
     * Do not edit the class manually.
     */
    var SREService = /** @class */ (function () {
        function SREService(httpClient, basePath, configuration) {
            this.httpClient = httpClient;
            this.basePath = 'http://localhost:8080/api/v2';
            this.defaultHeaders = new i1.HttpHeaders();
            this.configuration = new Configuration();
            if (configuration) {
                this.configuration = configuration;
            }
            if (typeof this.configuration.basePath !== 'string') {
                if (typeof basePath !== 'string') {
                    basePath = this.basePath;
                }
                this.configuration.basePath = basePath;
            }
            this.encoder = this.configuration.encoder || new CustomHttpParameterCodec();
        }
        // @ts-ignore
        SREService.prototype.addToHttpParams = function (httpParams, value, key) {
            if (typeof value === "object" && value instanceof Date === false) {
                httpParams = this.addToHttpParamsRecursive(httpParams, value);
            }
            else {
                httpParams = this.addToHttpParamsRecursive(httpParams, value, key);
            }
            return httpParams;
        };
        SREService.prototype.addToHttpParamsRecursive = function (httpParams, value, key) {
            var _this = this;
            if (value == null) {
                return httpParams;
            }
            if (typeof value === "object") {
                if (Array.isArray(value)) {
                    value.forEach(function (elem) { return httpParams = _this.addToHttpParamsRecursive(httpParams, elem, key); });
                }
                else if (value instanceof Date) {
                    if (key != null) {
                        httpParams = httpParams.append(key, value.toISOString().substr(0, 10));
                    }
                    else {
                        throw Error("key may not be null if value is Date");
                    }
                }
                else {
                    Object.keys(value).forEach(function (k) { return httpParams = _this.addToHttpParamsRecursive(httpParams, value[k], key != null ? key + "." + k : k); });
                }
            }
            else if (key != null) {
                httpParams = httpParams.append(key, value);
            }
            else {
                throw Error("key may not be null if value is not object or array");
            }
            return httpParams;
        };
        SREService.prototype.getApplicationHealth = function (observe, reportProgress, options) {
            if (observe === void 0) { observe = 'body'; }
            if (reportProgress === void 0) { reportProgress = false; }
            var localVarHeaders = this.defaultHeaders;
            var localVarHttpHeaderAcceptSelected = options && options.httpHeaderAccept;
            if (localVarHttpHeaderAcceptSelected === undefined) {
                // to determine the Accept header
                var httpHeaderAccepts = [
                    'application/json'
                ];
                localVarHttpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
            }
            if (localVarHttpHeaderAcceptSelected !== undefined) {
                localVarHeaders = localVarHeaders.set('Accept', localVarHttpHeaderAcceptSelected);
            }
            var localVarHttpContext = options && options.context;
            if (localVarHttpContext === undefined) {
                localVarHttpContext = new i1.HttpContext();
            }
            var responseType_ = 'json';
            if (localVarHttpHeaderAcceptSelected) {
                if (localVarHttpHeaderAcceptSelected.startsWith('text')) {
                    responseType_ = 'text';
                }
                else if (this.configuration.isJsonMime(localVarHttpHeaderAcceptSelected)) {
                    responseType_ = 'json';
                }
                else {
                    responseType_ = 'blob';
                }
            }
            return this.httpClient.get(this.configuration.basePath + "/health", {
                context: localVarHttpContext,
                responseType: responseType_,
                withCredentials: this.configuration.withCredentials,
                headers: localVarHeaders,
                observe: observe,
                reportProgress: reportProgress
            });
        };
        return SREService;
    }());
    SREService.ɵprov = i0__namespace.ɵɵdefineInjectable({ factory: function SREService_Factory() { return new SREService(i0__namespace.ɵɵinject(i1__namespace.HttpClient), i0__namespace.ɵɵinject(BASE_PATH, 8), i0__namespace.ɵɵinject(Configuration, 8)); }, token: SREService, providedIn: "root" });
    SREService.decorators = [
        { type: i0.Injectable, args: [{
                    providedIn: 'root'
                },] }
    ];
    SREService.ctorParameters = function () { return [
        { type: i1.HttpClient },
        { type: String, decorators: [{ type: i0.Optional }, { type: i0.Inject, args: [BASE_PATH,] }] },
        { type: Configuration, decorators: [{ type: i0.Optional }] }
    ]; };

    /**
     * clash-bot-webapp-service
     * Clash Bot Webapp Service to support League of Legends Clash tournament scheduling with Discord.
     *
     * The version of the OpenAPI document: 1.1.0
     * Contact: rixxroid@gmail.com
     *
     * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
     * https://openapi-generator.tech
     * Do not edit the class manually.
     */
    var TeamService = /** @class */ (function () {
        function TeamService(httpClient, basePath, configuration) {
            this.httpClient = httpClient;
            this.basePath = 'http://localhost:8080/api/v2';
            this.defaultHeaders = new i1.HttpHeaders();
            this.configuration = new Configuration();
            if (configuration) {
                this.configuration = configuration;
            }
            if (typeof this.configuration.basePath !== 'string') {
                if (typeof basePath !== 'string') {
                    basePath = this.basePath;
                }
                this.configuration.basePath = basePath;
            }
            this.encoder = this.configuration.encoder || new CustomHttpParameterCodec();
        }
        // @ts-ignore
        TeamService.prototype.addToHttpParams = function (httpParams, value, key) {
            if (typeof value === "object" && value instanceof Date === false) {
                httpParams = this.addToHttpParamsRecursive(httpParams, value);
            }
            else {
                httpParams = this.addToHttpParamsRecursive(httpParams, value, key);
            }
            return httpParams;
        };
        TeamService.prototype.addToHttpParamsRecursive = function (httpParams, value, key) {
            var _this = this;
            if (value == null) {
                return httpParams;
            }
            if (typeof value === "object") {
                if (Array.isArray(value)) {
                    value.forEach(function (elem) { return httpParams = _this.addToHttpParamsRecursive(httpParams, elem, key); });
                }
                else if (value instanceof Date) {
                    if (key != null) {
                        httpParams = httpParams.append(key, value.toISOString().substr(0, 10));
                    }
                    else {
                        throw Error("key may not be null if value is Date");
                    }
                }
                else {
                    Object.keys(value).forEach(function (k) { return httpParams = _this.addToHttpParamsRecursive(httpParams, value[k], key != null ? key + "." + k : k); });
                }
            }
            else if (key != null) {
                httpParams = httpParams.append(key, value);
            }
            else {
                throw Error("key may not be null if value is not object or array");
            }
            return httpParams;
        };
        TeamService.prototype.createNewTeam = function (createNewTeamRequest, observe, reportProgress, options) {
            if (observe === void 0) { observe = 'body'; }
            if (reportProgress === void 0) { reportProgress = false; }
            var localVarHeaders = this.defaultHeaders;
            var localVarHttpHeaderAcceptSelected = options && options.httpHeaderAccept;
            if (localVarHttpHeaderAcceptSelected === undefined) {
                // to determine the Accept header
                var httpHeaderAccepts = [
                    'application/json'
                ];
                localVarHttpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
            }
            if (localVarHttpHeaderAcceptSelected !== undefined) {
                localVarHeaders = localVarHeaders.set('Accept', localVarHttpHeaderAcceptSelected);
            }
            var localVarHttpContext = options && options.context;
            if (localVarHttpContext === undefined) {
                localVarHttpContext = new i1.HttpContext();
            }
            // to determine the Content-Type header
            var consumes = [
                'application/json'
            ];
            var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
            if (httpContentTypeSelected !== undefined) {
                localVarHeaders = localVarHeaders.set('Content-Type', httpContentTypeSelected);
            }
            var responseType_ = 'json';
            if (localVarHttpHeaderAcceptSelected) {
                if (localVarHttpHeaderAcceptSelected.startsWith('text')) {
                    responseType_ = 'text';
                }
                else if (this.configuration.isJsonMime(localVarHttpHeaderAcceptSelected)) {
                    responseType_ = 'json';
                }
                else {
                    responseType_ = 'blob';
                }
            }
            return this.httpClient.post(this.configuration.basePath + "/team", createNewTeamRequest, {
                context: localVarHttpContext,
                responseType: responseType_,
                withCredentials: this.configuration.withCredentials,
                headers: localVarHeaders,
                observe: observe,
                reportProgress: reportProgress
            });
        };
        TeamService.prototype.getTeam = function (serverId, name, tournament, day, observe, reportProgress, options) {
            if (observe === void 0) { observe = 'body'; }
            if (reportProgress === void 0) { reportProgress = false; }
            if (serverId === null || serverId === undefined) {
                throw new Error('Required parameter serverId was null or undefined when calling getTeam.');
            }
            var localVarQueryParameters = new i1.HttpParams({ encoder: this.encoder });
            if (name !== undefined && name !== null) {
                localVarQueryParameters = this.addToHttpParams(localVarQueryParameters, name, 'name');
            }
            if (serverId !== undefined && serverId !== null) {
                localVarQueryParameters = this.addToHttpParams(localVarQueryParameters, serverId, 'serverId');
            }
            if (tournament !== undefined && tournament !== null) {
                localVarQueryParameters = this.addToHttpParams(localVarQueryParameters, tournament, 'tournament');
            }
            if (day !== undefined && day !== null) {
                localVarQueryParameters = this.addToHttpParams(localVarQueryParameters, day, 'day');
            }
            var localVarHeaders = this.defaultHeaders;
            var localVarHttpHeaderAcceptSelected = options && options.httpHeaderAccept;
            if (localVarHttpHeaderAcceptSelected === undefined) {
                // to determine the Accept header
                var httpHeaderAccepts = [
                    'application/json'
                ];
                localVarHttpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
            }
            if (localVarHttpHeaderAcceptSelected !== undefined) {
                localVarHeaders = localVarHeaders.set('Accept', localVarHttpHeaderAcceptSelected);
            }
            var localVarHttpContext = options && options.context;
            if (localVarHttpContext === undefined) {
                localVarHttpContext = new i1.HttpContext();
            }
            var responseType_ = 'json';
            if (localVarHttpHeaderAcceptSelected) {
                if (localVarHttpHeaderAcceptSelected.startsWith('text')) {
                    responseType_ = 'text';
                }
                else if (this.configuration.isJsonMime(localVarHttpHeaderAcceptSelected)) {
                    responseType_ = 'json';
                }
                else {
                    responseType_ = 'blob';
                }
            }
            return this.httpClient.get(this.configuration.basePath + "/team", {
                context: localVarHttpContext,
                params: localVarQueryParameters,
                responseType: responseType_,
                withCredentials: this.configuration.withCredentials,
                headers: localVarHeaders,
                observe: observe,
                reportProgress: reportProgress
            });
        };
        TeamService.prototype.removePlayerFromTeam = function (name, serverId, tournament, tournamentDay, playerId, observe, reportProgress, options) {
            if (observe === void 0) { observe = 'body'; }
            if (reportProgress === void 0) { reportProgress = false; }
            if (name === null || name === undefined) {
                throw new Error('Required parameter name was null or undefined when calling removePlayerFromTeam.');
            }
            if (serverId === null || serverId === undefined) {
                throw new Error('Required parameter serverId was null or undefined when calling removePlayerFromTeam.');
            }
            if (tournament === null || tournament === undefined) {
                throw new Error('Required parameter tournament was null or undefined when calling removePlayerFromTeam.');
            }
            if (tournamentDay === null || tournamentDay === undefined) {
                throw new Error('Required parameter tournamentDay was null or undefined when calling removePlayerFromTeam.');
            }
            if (playerId === null || playerId === undefined) {
                throw new Error('Required parameter playerId was null or undefined when calling removePlayerFromTeam.');
            }
            var localVarQueryParameters = new i1.HttpParams({ encoder: this.encoder });
            if (name !== undefined && name !== null) {
                localVarQueryParameters = this.addToHttpParams(localVarQueryParameters, name, 'name');
            }
            if (serverId !== undefined && serverId !== null) {
                localVarQueryParameters = this.addToHttpParams(localVarQueryParameters, serverId, 'serverId');
            }
            if (tournament !== undefined && tournament !== null) {
                localVarQueryParameters = this.addToHttpParams(localVarQueryParameters, tournament, 'tournament');
            }
            if (tournamentDay !== undefined && tournamentDay !== null) {
                localVarQueryParameters = this.addToHttpParams(localVarQueryParameters, tournamentDay, 'tournamentDay');
            }
            if (playerId !== undefined && playerId !== null) {
                localVarQueryParameters = this.addToHttpParams(localVarQueryParameters, playerId, 'playerId');
            }
            var localVarHeaders = this.defaultHeaders;
            var localVarHttpHeaderAcceptSelected = options && options.httpHeaderAccept;
            if (localVarHttpHeaderAcceptSelected === undefined) {
                // to determine the Accept header
                var httpHeaderAccepts = [
                    'application/json'
                ];
                localVarHttpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
            }
            if (localVarHttpHeaderAcceptSelected !== undefined) {
                localVarHeaders = localVarHeaders.set('Accept', localVarHttpHeaderAcceptSelected);
            }
            var localVarHttpContext = options && options.context;
            if (localVarHttpContext === undefined) {
                localVarHttpContext = new i1.HttpContext();
            }
            var responseType_ = 'json';
            if (localVarHttpHeaderAcceptSelected) {
                if (localVarHttpHeaderAcceptSelected.startsWith('text')) {
                    responseType_ = 'text';
                }
                else if (this.configuration.isJsonMime(localVarHttpHeaderAcceptSelected)) {
                    responseType_ = 'json';
                }
                else {
                    responseType_ = 'blob';
                }
            }
            return this.httpClient.delete(this.configuration.basePath + "/team", {
                context: localVarHttpContext,
                params: localVarQueryParameters,
                responseType: responseType_,
                withCredentials: this.configuration.withCredentials,
                headers: localVarHeaders,
                observe: observe,
                reportProgress: reportProgress
            });
        };
        TeamService.prototype.updateTeam = function (updateTeamRequest, observe, reportProgress, options) {
            if (observe === void 0) { observe = 'body'; }
            if (reportProgress === void 0) { reportProgress = false; }
            var localVarHeaders = this.defaultHeaders;
            var localVarHttpHeaderAcceptSelected = options && options.httpHeaderAccept;
            if (localVarHttpHeaderAcceptSelected === undefined) {
                // to determine the Accept header
                var httpHeaderAccepts = [
                    'application/json'
                ];
                localVarHttpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
            }
            if (localVarHttpHeaderAcceptSelected !== undefined) {
                localVarHeaders = localVarHeaders.set('Accept', localVarHttpHeaderAcceptSelected);
            }
            var localVarHttpContext = options && options.context;
            if (localVarHttpContext === undefined) {
                localVarHttpContext = new i1.HttpContext();
            }
            // to determine the Content-Type header
            var consumes = [
                'application/json'
            ];
            var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
            if (httpContentTypeSelected !== undefined) {
                localVarHeaders = localVarHeaders.set('Content-Type', httpContentTypeSelected);
            }
            var responseType_ = 'json';
            if (localVarHttpHeaderAcceptSelected) {
                if (localVarHttpHeaderAcceptSelected.startsWith('text')) {
                    responseType_ = 'text';
                }
                else if (this.configuration.isJsonMime(localVarHttpHeaderAcceptSelected)) {
                    responseType_ = 'json';
                }
                else {
                    responseType_ = 'blob';
                }
            }
            return this.httpClient.patch(this.configuration.basePath + "/team", updateTeamRequest, {
                context: localVarHttpContext,
                responseType: responseType_,
                withCredentials: this.configuration.withCredentials,
                headers: localVarHeaders,
                observe: observe,
                reportProgress: reportProgress
            });
        };
        return TeamService;
    }());
    TeamService.ɵprov = i0__namespace.ɵɵdefineInjectable({ factory: function TeamService_Factory() { return new TeamService(i0__namespace.ɵɵinject(i1__namespace.HttpClient), i0__namespace.ɵɵinject(BASE_PATH, 8), i0__namespace.ɵɵinject(Configuration, 8)); }, token: TeamService, providedIn: "root" });
    TeamService.decorators = [
        { type: i0.Injectable, args: [{
                    providedIn: 'root'
                },] }
    ];
    TeamService.ctorParameters = function () { return [
        { type: i1.HttpClient },
        { type: String, decorators: [{ type: i0.Optional }, { type: i0.Inject, args: [BASE_PATH,] }] },
        { type: Configuration, decorators: [{ type: i0.Optional }] }
    ]; };

    /**
     * clash-bot-webapp-service
     * Clash Bot Webapp Service to support League of Legends Clash tournament scheduling with Discord.
     *
     * The version of the OpenAPI document: 1.1.0
     * Contact: rixxroid@gmail.com
     *
     * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
     * https://openapi-generator.tech
     * Do not edit the class manually.
     */
    var TentativeService = /** @class */ (function () {
        function TentativeService(httpClient, basePath, configuration) {
            this.httpClient = httpClient;
            this.basePath = 'http://localhost:8080/api/v2';
            this.defaultHeaders = new i1.HttpHeaders();
            this.configuration = new Configuration();
            if (configuration) {
                this.configuration = configuration;
            }
            if (typeof this.configuration.basePath !== 'string') {
                if (typeof basePath !== 'string') {
                    basePath = this.basePath;
                }
                this.configuration.basePath = basePath;
            }
            this.encoder = this.configuration.encoder || new CustomHttpParameterCodec();
        }
        // @ts-ignore
        TentativeService.prototype.addToHttpParams = function (httpParams, value, key) {
            if (typeof value === "object" && value instanceof Date === false) {
                httpParams = this.addToHttpParamsRecursive(httpParams, value);
            }
            else {
                httpParams = this.addToHttpParamsRecursive(httpParams, value, key);
            }
            return httpParams;
        };
        TentativeService.prototype.addToHttpParamsRecursive = function (httpParams, value, key) {
            var _this = this;
            if (value == null) {
                return httpParams;
            }
            if (typeof value === "object") {
                if (Array.isArray(value)) {
                    value.forEach(function (elem) { return httpParams = _this.addToHttpParamsRecursive(httpParams, elem, key); });
                }
                else if (value instanceof Date) {
                    if (key != null) {
                        httpParams = httpParams.append(key, value.toISOString().substr(0, 10));
                    }
                    else {
                        throw Error("key may not be null if value is Date");
                    }
                }
                else {
                    Object.keys(value).forEach(function (k) { return httpParams = _this.addToHttpParamsRecursive(httpParams, value[k], key != null ? key + "." + k : k); });
                }
            }
            else if (key != null) {
                httpParams = httpParams.append(key, value);
            }
            else {
                throw Error("key may not be null if value is not object or array");
            }
            return httpParams;
        };
        TentativeService.prototype.getTentativeDetails = function (serverId, tournamentName, tournamentDay, observe, reportProgress, options) {
            if (observe === void 0) { observe = 'body'; }
            if (reportProgress === void 0) { reportProgress = false; }
            if (serverId === null || serverId === undefined) {
                throw new Error('Required parameter serverId was null or undefined when calling getTentativeDetails.');
            }
            var localVarQueryParameters = new i1.HttpParams({ encoder: this.encoder });
            if (serverId !== undefined && serverId !== null) {
                localVarQueryParameters = this.addToHttpParams(localVarQueryParameters, serverId, 'serverId');
            }
            if (tournamentName !== undefined && tournamentName !== null) {
                localVarQueryParameters = this.addToHttpParams(localVarQueryParameters, tournamentName, 'tournamentName');
            }
            if (tournamentDay !== undefined && tournamentDay !== null) {
                localVarQueryParameters = this.addToHttpParams(localVarQueryParameters, tournamentDay, 'tournamentDay');
            }
            var localVarHeaders = this.defaultHeaders;
            var localVarHttpHeaderAcceptSelected = options && options.httpHeaderAccept;
            if (localVarHttpHeaderAcceptSelected === undefined) {
                // to determine the Accept header
                var httpHeaderAccepts = [
                    'application/json'
                ];
                localVarHttpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
            }
            if (localVarHttpHeaderAcceptSelected !== undefined) {
                localVarHeaders = localVarHeaders.set('Accept', localVarHttpHeaderAcceptSelected);
            }
            var localVarHttpContext = options && options.context;
            if (localVarHttpContext === undefined) {
                localVarHttpContext = new i1.HttpContext();
            }
            var responseType_ = 'json';
            if (localVarHttpHeaderAcceptSelected) {
                if (localVarHttpHeaderAcceptSelected.startsWith('text')) {
                    responseType_ = 'text';
                }
                else if (this.configuration.isJsonMime(localVarHttpHeaderAcceptSelected)) {
                    responseType_ = 'json';
                }
                else {
                    responseType_ = 'blob';
                }
            }
            return this.httpClient.get(this.configuration.basePath + "/tentative", {
                context: localVarHttpContext,
                params: localVarQueryParameters,
                responseType: responseType_,
                withCredentials: this.configuration.withCredentials,
                headers: localVarHeaders,
                observe: observe,
                reportProgress: reportProgress
            });
        };
        TentativeService.prototype.placePlayerOnTentative = function (placePlayerOnTentativeRequest, observe, reportProgress, options) {
            if (observe === void 0) { observe = 'body'; }
            if (reportProgress === void 0) { reportProgress = false; }
            var localVarHeaders = this.defaultHeaders;
            var localVarHttpHeaderAcceptSelected = options && options.httpHeaderAccept;
            if (localVarHttpHeaderAcceptSelected === undefined) {
                // to determine the Accept header
                var httpHeaderAccepts = [
                    'application/json'
                ];
                localVarHttpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
            }
            if (localVarHttpHeaderAcceptSelected !== undefined) {
                localVarHeaders = localVarHeaders.set('Accept', localVarHttpHeaderAcceptSelected);
            }
            var localVarHttpContext = options && options.context;
            if (localVarHttpContext === undefined) {
                localVarHttpContext = new i1.HttpContext();
            }
            // to determine the Content-Type header
            var consumes = [
                'application/json'
            ];
            var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
            if (httpContentTypeSelected !== undefined) {
                localVarHeaders = localVarHeaders.set('Content-Type', httpContentTypeSelected);
            }
            var responseType_ = 'json';
            if (localVarHttpHeaderAcceptSelected) {
                if (localVarHttpHeaderAcceptSelected.startsWith('text')) {
                    responseType_ = 'text';
                }
                else if (this.configuration.isJsonMime(localVarHttpHeaderAcceptSelected)) {
                    responseType_ = 'json';
                }
                else {
                    responseType_ = 'blob';
                }
            }
            return this.httpClient.post(this.configuration.basePath + "/tentative", placePlayerOnTentativeRequest, {
                context: localVarHttpContext,
                responseType: responseType_,
                withCredentials: this.configuration.withCredentials,
                headers: localVarHeaders,
                observe: observe,
                reportProgress: reportProgress
            });
        };
        TentativeService.prototype.removePlayerFromTentative = function (serverId, playerId, tournament, tournamentDay, observe, reportProgress, options) {
            if (observe === void 0) { observe = 'body'; }
            if (reportProgress === void 0) { reportProgress = false; }
            if (serverId === null || serverId === undefined) {
                throw new Error('Required parameter serverId was null or undefined when calling removePlayerFromTentative.');
            }
            if (playerId === null || playerId === undefined) {
                throw new Error('Required parameter playerId was null or undefined when calling removePlayerFromTentative.');
            }
            if (tournament === null || tournament === undefined) {
                throw new Error('Required parameter tournament was null or undefined when calling removePlayerFromTentative.');
            }
            if (tournamentDay === null || tournamentDay === undefined) {
                throw new Error('Required parameter tournamentDay was null or undefined when calling removePlayerFromTentative.');
            }
            var localVarQueryParameters = new i1.HttpParams({ encoder: this.encoder });
            if (serverId !== undefined && serverId !== null) {
                localVarQueryParameters = this.addToHttpParams(localVarQueryParameters, serverId, 'serverId');
            }
            if (playerId !== undefined && playerId !== null) {
                localVarQueryParameters = this.addToHttpParams(localVarQueryParameters, playerId, 'playerId');
            }
            if (tournament !== undefined && tournament !== null) {
                localVarQueryParameters = this.addToHttpParams(localVarQueryParameters, tournament, 'tournament');
            }
            if (tournamentDay !== undefined && tournamentDay !== null) {
                localVarQueryParameters = this.addToHttpParams(localVarQueryParameters, tournamentDay, 'tournamentDay');
            }
            var localVarHeaders = this.defaultHeaders;
            var localVarHttpHeaderAcceptSelected = options && options.httpHeaderAccept;
            if (localVarHttpHeaderAcceptSelected === undefined) {
                // to determine the Accept header
                var httpHeaderAccepts = [
                    'application/json'
                ];
                localVarHttpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
            }
            if (localVarHttpHeaderAcceptSelected !== undefined) {
                localVarHeaders = localVarHeaders.set('Accept', localVarHttpHeaderAcceptSelected);
            }
            var localVarHttpContext = options && options.context;
            if (localVarHttpContext === undefined) {
                localVarHttpContext = new i1.HttpContext();
            }
            var responseType_ = 'json';
            if (localVarHttpHeaderAcceptSelected) {
                if (localVarHttpHeaderAcceptSelected.startsWith('text')) {
                    responseType_ = 'text';
                }
                else if (this.configuration.isJsonMime(localVarHttpHeaderAcceptSelected)) {
                    responseType_ = 'json';
                }
                else {
                    responseType_ = 'blob';
                }
            }
            return this.httpClient.delete(this.configuration.basePath + "/tentative", {
                context: localVarHttpContext,
                params: localVarQueryParameters,
                responseType: responseType_,
                withCredentials: this.configuration.withCredentials,
                headers: localVarHeaders,
                observe: observe,
                reportProgress: reportProgress
            });
        };
        return TentativeService;
    }());
    TentativeService.ɵprov = i0__namespace.ɵɵdefineInjectable({ factory: function TentativeService_Factory() { return new TentativeService(i0__namespace.ɵɵinject(i1__namespace.HttpClient), i0__namespace.ɵɵinject(BASE_PATH, 8), i0__namespace.ɵɵinject(Configuration, 8)); }, token: TentativeService, providedIn: "root" });
    TentativeService.decorators = [
        { type: i0.Injectable, args: [{
                    providedIn: 'root'
                },] }
    ];
    TentativeService.ctorParameters = function () { return [
        { type: i1.HttpClient },
        { type: String, decorators: [{ type: i0.Optional }, { type: i0.Inject, args: [BASE_PATH,] }] },
        { type: Configuration, decorators: [{ type: i0.Optional }] }
    ]; };

    /**
     * clash-bot-webapp-service
     * Clash Bot Webapp Service to support League of Legends Clash tournament scheduling with Discord.
     *
     * The version of the OpenAPI document: 1.1.0
     * Contact: rixxroid@gmail.com
     *
     * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
     * https://openapi-generator.tech
     * Do not edit the class manually.
     */
    var TournamentService = /** @class */ (function () {
        function TournamentService(httpClient, basePath, configuration) {
            this.httpClient = httpClient;
            this.basePath = 'http://localhost:8080/api/v2';
            this.defaultHeaders = new i1.HttpHeaders();
            this.configuration = new Configuration();
            if (configuration) {
                this.configuration = configuration;
            }
            if (typeof this.configuration.basePath !== 'string') {
                if (typeof basePath !== 'string') {
                    basePath = this.basePath;
                }
                this.configuration.basePath = basePath;
            }
            this.encoder = this.configuration.encoder || new CustomHttpParameterCodec();
        }
        // @ts-ignore
        TournamentService.prototype.addToHttpParams = function (httpParams, value, key) {
            if (typeof value === "object" && value instanceof Date === false) {
                httpParams = this.addToHttpParamsRecursive(httpParams, value);
            }
            else {
                httpParams = this.addToHttpParamsRecursive(httpParams, value, key);
            }
            return httpParams;
        };
        TournamentService.prototype.addToHttpParamsRecursive = function (httpParams, value, key) {
            var _this = this;
            if (value == null) {
                return httpParams;
            }
            if (typeof value === "object") {
                if (Array.isArray(value)) {
                    value.forEach(function (elem) { return httpParams = _this.addToHttpParamsRecursive(httpParams, elem, key); });
                }
                else if (value instanceof Date) {
                    if (key != null) {
                        httpParams = httpParams.append(key, value.toISOString().substr(0, 10));
                    }
                    else {
                        throw Error("key may not be null if value is Date");
                    }
                }
                else {
                    Object.keys(value).forEach(function (k) { return httpParams = _this.addToHttpParamsRecursive(httpParams, value[k], key != null ? key + "." + k : k); });
                }
            }
            else if (key != null) {
                httpParams = httpParams.append(key, value);
            }
            else {
                throw Error("key may not be null if value is not object or array");
            }
            return httpParams;
        };
        TournamentService.prototype.getTournaments = function (tournament, day, observe, reportProgress, options) {
            if (observe === void 0) { observe = 'body'; }
            if (reportProgress === void 0) { reportProgress = false; }
            var localVarQueryParameters = new i1.HttpParams({ encoder: this.encoder });
            if (tournament !== undefined && tournament !== null) {
                localVarQueryParameters = this.addToHttpParams(localVarQueryParameters, tournament, 'tournament');
            }
            if (day !== undefined && day !== null) {
                localVarQueryParameters = this.addToHttpParams(localVarQueryParameters, day, 'day');
            }
            var localVarHeaders = this.defaultHeaders;
            var localVarHttpHeaderAcceptSelected = options && options.httpHeaderAccept;
            if (localVarHttpHeaderAcceptSelected === undefined) {
                // to determine the Accept header
                var httpHeaderAccepts = [
                    'application/json'
                ];
                localVarHttpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
            }
            if (localVarHttpHeaderAcceptSelected !== undefined) {
                localVarHeaders = localVarHeaders.set('Accept', localVarHttpHeaderAcceptSelected);
            }
            var localVarHttpContext = options && options.context;
            if (localVarHttpContext === undefined) {
                localVarHttpContext = new i1.HttpContext();
            }
            var responseType_ = 'json';
            if (localVarHttpHeaderAcceptSelected) {
                if (localVarHttpHeaderAcceptSelected.startsWith('text')) {
                    responseType_ = 'text';
                }
                else if (this.configuration.isJsonMime(localVarHttpHeaderAcceptSelected)) {
                    responseType_ = 'json';
                }
                else {
                    responseType_ = 'blob';
                }
            }
            return this.httpClient.get(this.configuration.basePath + "/tournaments", {
                context: localVarHttpContext,
                params: localVarQueryParameters,
                responseType: responseType_,
                withCredentials: this.configuration.withCredentials,
                headers: localVarHeaders,
                observe: observe,
                reportProgress: reportProgress
            });
        };
        return TournamentService;
    }());
    TournamentService.ɵprov = i0__namespace.ɵɵdefineInjectable({ factory: function TournamentService_Factory() { return new TournamentService(i0__namespace.ɵɵinject(i1__namespace.HttpClient), i0__namespace.ɵɵinject(BASE_PATH, 8), i0__namespace.ɵɵinject(Configuration, 8)); }, token: TournamentService, providedIn: "root" });
    TournamentService.decorators = [
        { type: i0.Injectable, args: [{
                    providedIn: 'root'
                },] }
    ];
    TournamentService.ctorParameters = function () { return [
        { type: i1.HttpClient },
        { type: String, decorators: [{ type: i0.Optional }, { type: i0.Inject, args: [BASE_PATH,] }] },
        { type: Configuration, decorators: [{ type: i0.Optional }] }
    ]; };

    /**
     * clash-bot-webapp-service
     * Clash Bot Webapp Service to support League of Legends Clash tournament scheduling with Discord.
     *
     * The version of the OpenAPI document: 1.1.0
     * Contact: rixxroid@gmail.com
     *
     * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
     * https://openapi-generator.tech
     * Do not edit the class manually.
     */
    var UserService = /** @class */ (function () {
        function UserService(httpClient, basePath, configuration) {
            this.httpClient = httpClient;
            this.basePath = 'http://localhost:8080/api/v2';
            this.defaultHeaders = new i1.HttpHeaders();
            this.configuration = new Configuration();
            if (configuration) {
                this.configuration = configuration;
            }
            if (typeof this.configuration.basePath !== 'string') {
                if (typeof basePath !== 'string') {
                    basePath = this.basePath;
                }
                this.configuration.basePath = basePath;
            }
            this.encoder = this.configuration.encoder || new CustomHttpParameterCodec();
        }
        // @ts-ignore
        UserService.prototype.addToHttpParams = function (httpParams, value, key) {
            if (typeof value === "object" && value instanceof Date === false) {
                httpParams = this.addToHttpParamsRecursive(httpParams, value);
            }
            else {
                httpParams = this.addToHttpParamsRecursive(httpParams, value, key);
            }
            return httpParams;
        };
        UserService.prototype.addToHttpParamsRecursive = function (httpParams, value, key) {
            var _this = this;
            if (value == null) {
                return httpParams;
            }
            if (typeof value === "object") {
                if (Array.isArray(value)) {
                    value.forEach(function (elem) { return httpParams = _this.addToHttpParamsRecursive(httpParams, elem, key); });
                }
                else if (value instanceof Date) {
                    if (key != null) {
                        httpParams = httpParams.append(key, value.toISOString().substr(0, 10));
                    }
                    else {
                        throw Error("key may not be null if value is Date");
                    }
                }
                else {
                    Object.keys(value).forEach(function (k) { return httpParams = _this.addToHttpParamsRecursive(httpParams, value[k], key != null ? key + "." + k : k); });
                }
            }
            else if (key != null) {
                httpParams = httpParams.append(key, value);
            }
            else {
                throw Error("key may not be null if value is not object or array");
            }
            return httpParams;
        };
        UserService.prototype.addToListOfPreferredChampions = function (id, addToListOfPreferredChampionsRequest, observe, reportProgress, options) {
            if (observe === void 0) { observe = 'body'; }
            if (reportProgress === void 0) { reportProgress = false; }
            if (id === null || id === undefined) {
                throw new Error('Required parameter id was null or undefined when calling addToListOfPreferredChampions.');
            }
            var localVarHeaders = this.defaultHeaders;
            var localVarHttpHeaderAcceptSelected = options && options.httpHeaderAccept;
            if (localVarHttpHeaderAcceptSelected === undefined) {
                // to determine the Accept header
                var httpHeaderAccepts = [
                    'application/json'
                ];
                localVarHttpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
            }
            if (localVarHttpHeaderAcceptSelected !== undefined) {
                localVarHeaders = localVarHeaders.set('Accept', localVarHttpHeaderAcceptSelected);
            }
            var localVarHttpContext = options && options.context;
            if (localVarHttpContext === undefined) {
                localVarHttpContext = new i1.HttpContext();
            }
            // to determine the Content-Type header
            var consumes = [
                'application/json'
            ];
            var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
            if (httpContentTypeSelected !== undefined) {
                localVarHeaders = localVarHeaders.set('Content-Type', httpContentTypeSelected);
            }
            var responseType_ = 'json';
            if (localVarHttpHeaderAcceptSelected) {
                if (localVarHttpHeaderAcceptSelected.startsWith('text')) {
                    responseType_ = 'text';
                }
                else if (this.configuration.isJsonMime(localVarHttpHeaderAcceptSelected)) {
                    responseType_ = 'json';
                }
                else {
                    responseType_ = 'blob';
                }
            }
            return this.httpClient.patch(this.configuration.basePath + "/user/" + encodeURIComponent(String(id)) + "/champions", addToListOfPreferredChampionsRequest, {
                context: localVarHttpContext,
                responseType: responseType_,
                withCredentials: this.configuration.withCredentials,
                headers: localVarHeaders,
                observe: observe,
                reportProgress: reportProgress
            });
        };
        UserService.prototype.createNewListOfPreferredChampions = function (id, createNewListOfPreferredChampionsRequest, observe, reportProgress, options) {
            if (observe === void 0) { observe = 'body'; }
            if (reportProgress === void 0) { reportProgress = false; }
            if (id === null || id === undefined) {
                throw new Error('Required parameter id was null or undefined when calling createNewListOfPreferredChampions.');
            }
            var localVarHeaders = this.defaultHeaders;
            var localVarHttpHeaderAcceptSelected = options && options.httpHeaderAccept;
            if (localVarHttpHeaderAcceptSelected === undefined) {
                // to determine the Accept header
                var httpHeaderAccepts = [
                    'application/json'
                ];
                localVarHttpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
            }
            if (localVarHttpHeaderAcceptSelected !== undefined) {
                localVarHeaders = localVarHeaders.set('Accept', localVarHttpHeaderAcceptSelected);
            }
            var localVarHttpContext = options && options.context;
            if (localVarHttpContext === undefined) {
                localVarHttpContext = new i1.HttpContext();
            }
            // to determine the Content-Type header
            var consumes = [
                'application/json'
            ];
            var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
            if (httpContentTypeSelected !== undefined) {
                localVarHeaders = localVarHeaders.set('Content-Type', httpContentTypeSelected);
            }
            var responseType_ = 'json';
            if (localVarHttpHeaderAcceptSelected) {
                if (localVarHttpHeaderAcceptSelected.startsWith('text')) {
                    responseType_ = 'text';
                }
                else if (this.configuration.isJsonMime(localVarHttpHeaderAcceptSelected)) {
                    responseType_ = 'json';
                }
                else {
                    responseType_ = 'blob';
                }
            }
            return this.httpClient.post(this.configuration.basePath + "/user/" + encodeURIComponent(String(id)) + "/champions", createNewListOfPreferredChampionsRequest, {
                context: localVarHttpContext,
                responseType: responseType_,
                withCredentials: this.configuration.withCredentials,
                headers: localVarHeaders,
                observe: observe,
                reportProgress: reportProgress
            });
        };
        UserService.prototype.createUser = function (createUserRequest, observe, reportProgress, options) {
            if (observe === void 0) { observe = 'body'; }
            if (reportProgress === void 0) { reportProgress = false; }
            var localVarHeaders = this.defaultHeaders;
            var localVarHttpHeaderAcceptSelected = options && options.httpHeaderAccept;
            if (localVarHttpHeaderAcceptSelected === undefined) {
                // to determine the Accept header
                var httpHeaderAccepts = [
                    'application/json'
                ];
                localVarHttpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
            }
            if (localVarHttpHeaderAcceptSelected !== undefined) {
                localVarHeaders = localVarHeaders.set('Accept', localVarHttpHeaderAcceptSelected);
            }
            var localVarHttpContext = options && options.context;
            if (localVarHttpContext === undefined) {
                localVarHttpContext = new i1.HttpContext();
            }
            // to determine the Content-Type header
            var consumes = [
                'application/json'
            ];
            var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
            if (httpContentTypeSelected !== undefined) {
                localVarHeaders = localVarHeaders.set('Content-Type', httpContentTypeSelected);
            }
            var responseType_ = 'json';
            if (localVarHttpHeaderAcceptSelected) {
                if (localVarHttpHeaderAcceptSelected.startsWith('text')) {
                    responseType_ = 'text';
                }
                else if (this.configuration.isJsonMime(localVarHttpHeaderAcceptSelected)) {
                    responseType_ = 'json';
                }
                else {
                    responseType_ = 'blob';
                }
            }
            return this.httpClient.post(this.configuration.basePath + "/user", createUserRequest, {
                context: localVarHttpContext,
                responseType: responseType_,
                withCredentials: this.configuration.withCredentials,
                headers: localVarHeaders,
                observe: observe,
                reportProgress: reportProgress
            });
        };
        UserService.prototype.getUser = function (id, observe, reportProgress, options) {
            if (observe === void 0) { observe = 'body'; }
            if (reportProgress === void 0) { reportProgress = false; }
            if (id === null || id === undefined) {
                throw new Error('Required parameter id was null or undefined when calling getUser.');
            }
            var localVarQueryParameters = new i1.HttpParams({ encoder: this.encoder });
            if (id !== undefined && id !== null) {
                localVarQueryParameters = this.addToHttpParams(localVarQueryParameters, id, 'id');
            }
            var localVarHeaders = this.defaultHeaders;
            var localVarHttpHeaderAcceptSelected = options && options.httpHeaderAccept;
            if (localVarHttpHeaderAcceptSelected === undefined) {
                // to determine the Accept header
                var httpHeaderAccepts = [
                    'application/json'
                ];
                localVarHttpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
            }
            if (localVarHttpHeaderAcceptSelected !== undefined) {
                localVarHeaders = localVarHeaders.set('Accept', localVarHttpHeaderAcceptSelected);
            }
            var localVarHttpContext = options && options.context;
            if (localVarHttpContext === undefined) {
                localVarHttpContext = new i1.HttpContext();
            }
            var responseType_ = 'json';
            if (localVarHttpHeaderAcceptSelected) {
                if (localVarHttpHeaderAcceptSelected.startsWith('text')) {
                    responseType_ = 'text';
                }
                else if (this.configuration.isJsonMime(localVarHttpHeaderAcceptSelected)) {
                    responseType_ = 'json';
                }
                else {
                    responseType_ = 'blob';
                }
            }
            return this.httpClient.get(this.configuration.basePath + "/user", {
                context: localVarHttpContext,
                params: localVarQueryParameters,
                responseType: responseType_,
                withCredentials: this.configuration.withCredentials,
                headers: localVarHeaders,
                observe: observe,
                reportProgress: reportProgress
            });
        };
        UserService.prototype.removeFromListOfPreferredChampions = function (id, champion, observe, reportProgress, options) {
            if (observe === void 0) { observe = 'body'; }
            if (reportProgress === void 0) { reportProgress = false; }
            if (id === null || id === undefined) {
                throw new Error('Required parameter id was null or undefined when calling removeFromListOfPreferredChampions.');
            }
            if (champion === null || champion === undefined) {
                throw new Error('Required parameter champion was null or undefined when calling removeFromListOfPreferredChampions.');
            }
            var localVarQueryParameters = new i1.HttpParams({ encoder: this.encoder });
            if (champion !== undefined && champion !== null) {
                localVarQueryParameters = this.addToHttpParams(localVarQueryParameters, champion, 'champion');
            }
            var localVarHeaders = this.defaultHeaders;
            var localVarHttpHeaderAcceptSelected = options && options.httpHeaderAccept;
            if (localVarHttpHeaderAcceptSelected === undefined) {
                // to determine the Accept header
                var httpHeaderAccepts = [
                    'application/json'
                ];
                localVarHttpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
            }
            if (localVarHttpHeaderAcceptSelected !== undefined) {
                localVarHeaders = localVarHeaders.set('Accept', localVarHttpHeaderAcceptSelected);
            }
            var localVarHttpContext = options && options.context;
            if (localVarHttpContext === undefined) {
                localVarHttpContext = new i1.HttpContext();
            }
            var responseType_ = 'json';
            if (localVarHttpHeaderAcceptSelected) {
                if (localVarHttpHeaderAcceptSelected.startsWith('text')) {
                    responseType_ = 'text';
                }
                else if (this.configuration.isJsonMime(localVarHttpHeaderAcceptSelected)) {
                    responseType_ = 'json';
                }
                else {
                    responseType_ = 'blob';
                }
            }
            return this.httpClient.delete(this.configuration.basePath + "/user/" + encodeURIComponent(String(id)) + "/champions", {
                context: localVarHttpContext,
                params: localVarQueryParameters,
                responseType: responseType_,
                withCredentials: this.configuration.withCredentials,
                headers: localVarHeaders,
                observe: observe,
                reportProgress: reportProgress
            });
        };
        UserService.prototype.retrieveListOfUserPreferredChampions = function (id, observe, reportProgress, options) {
            if (observe === void 0) { observe = 'body'; }
            if (reportProgress === void 0) { reportProgress = false; }
            if (id === null || id === undefined) {
                throw new Error('Required parameter id was null or undefined when calling retrieveListOfUserPreferredChampions.');
            }
            var localVarHeaders = this.defaultHeaders;
            var localVarHttpHeaderAcceptSelected = options && options.httpHeaderAccept;
            if (localVarHttpHeaderAcceptSelected === undefined) {
                // to determine the Accept header
                var httpHeaderAccepts = [
                    'application/json'
                ];
                localVarHttpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
            }
            if (localVarHttpHeaderAcceptSelected !== undefined) {
                localVarHeaders = localVarHeaders.set('Accept', localVarHttpHeaderAcceptSelected);
            }
            var localVarHttpContext = options && options.context;
            if (localVarHttpContext === undefined) {
                localVarHttpContext = new i1.HttpContext();
            }
            var responseType_ = 'json';
            if (localVarHttpHeaderAcceptSelected) {
                if (localVarHttpHeaderAcceptSelected.startsWith('text')) {
                    responseType_ = 'text';
                }
                else if (this.configuration.isJsonMime(localVarHttpHeaderAcceptSelected)) {
                    responseType_ = 'json';
                }
                else {
                    responseType_ = 'blob';
                }
            }
            return this.httpClient.get(this.configuration.basePath + "/user/" + encodeURIComponent(String(id)) + "/champions", {
                context: localVarHttpContext,
                responseType: responseType_,
                withCredentials: this.configuration.withCredentials,
                headers: localVarHeaders,
                observe: observe,
                reportProgress: reportProgress
            });
        };
        UserService.prototype.retrieveUserSubscriptions = function (id, observe, reportProgress, options) {
            if (observe === void 0) { observe = 'body'; }
            if (reportProgress === void 0) { reportProgress = false; }
            if (id === null || id === undefined) {
                throw new Error('Required parameter id was null or undefined when calling retrieveUserSubscriptions.');
            }
            var localVarHeaders = this.defaultHeaders;
            var localVarHttpHeaderAcceptSelected = options && options.httpHeaderAccept;
            if (localVarHttpHeaderAcceptSelected === undefined) {
                // to determine the Accept header
                var httpHeaderAccepts = [
                    'application/json'
                ];
                localVarHttpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
            }
            if (localVarHttpHeaderAcceptSelected !== undefined) {
                localVarHeaders = localVarHeaders.set('Accept', localVarHttpHeaderAcceptSelected);
            }
            var localVarHttpContext = options && options.context;
            if (localVarHttpContext === undefined) {
                localVarHttpContext = new i1.HttpContext();
            }
            var responseType_ = 'json';
            if (localVarHttpHeaderAcceptSelected) {
                if (localVarHttpHeaderAcceptSelected.startsWith('text')) {
                    responseType_ = 'text';
                }
                else if (this.configuration.isJsonMime(localVarHttpHeaderAcceptSelected)) {
                    responseType_ = 'json';
                }
                else {
                    responseType_ = 'blob';
                }
            }
            return this.httpClient.get(this.configuration.basePath + "/user/" + encodeURIComponent(String(id)) + "/subscriptions", {
                context: localVarHttpContext,
                responseType: responseType_,
                withCredentials: this.configuration.withCredentials,
                headers: localVarHeaders,
                observe: observe,
                reportProgress: reportProgress
            });
        };
        UserService.prototype.subscribeUser = function (id, observe, reportProgress, options) {
            if (observe === void 0) { observe = 'body'; }
            if (reportProgress === void 0) { reportProgress = false; }
            if (id === null || id === undefined) {
                throw new Error('Required parameter id was null or undefined when calling subscribeUser.');
            }
            var localVarHeaders = this.defaultHeaders;
            var localVarHttpHeaderAcceptSelected = options && options.httpHeaderAccept;
            if (localVarHttpHeaderAcceptSelected === undefined) {
                // to determine the Accept header
                var httpHeaderAccepts = [
                    'application/json'
                ];
                localVarHttpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
            }
            if (localVarHttpHeaderAcceptSelected !== undefined) {
                localVarHeaders = localVarHeaders.set('Accept', localVarHttpHeaderAcceptSelected);
            }
            var localVarHttpContext = options && options.context;
            if (localVarHttpContext === undefined) {
                localVarHttpContext = new i1.HttpContext();
            }
            var responseType_ = 'json';
            if (localVarHttpHeaderAcceptSelected) {
                if (localVarHttpHeaderAcceptSelected.startsWith('text')) {
                    responseType_ = 'text';
                }
                else if (this.configuration.isJsonMime(localVarHttpHeaderAcceptSelected)) {
                    responseType_ = 'json';
                }
                else {
                    responseType_ = 'blob';
                }
            }
            return this.httpClient.post(this.configuration.basePath + "/user/" + encodeURIComponent(String(id)) + "/subscriptions", null, {
                context: localVarHttpContext,
                responseType: responseType_,
                withCredentials: this.configuration.withCredentials,
                headers: localVarHeaders,
                observe: observe,
                reportProgress: reportProgress
            });
        };
        UserService.prototype.unsubscribeUser = function (id, observe, reportProgress, options) {
            if (observe === void 0) { observe = 'body'; }
            if (reportProgress === void 0) { reportProgress = false; }
            if (id === null || id === undefined) {
                throw new Error('Required parameter id was null or undefined when calling unsubscribeUser.');
            }
            var localVarHeaders = this.defaultHeaders;
            var localVarHttpHeaderAcceptSelected = options && options.httpHeaderAccept;
            if (localVarHttpHeaderAcceptSelected === undefined) {
                // to determine the Accept header
                var httpHeaderAccepts = [
                    'application/json'
                ];
                localVarHttpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
            }
            if (localVarHttpHeaderAcceptSelected !== undefined) {
                localVarHeaders = localVarHeaders.set('Accept', localVarHttpHeaderAcceptSelected);
            }
            var localVarHttpContext = options && options.context;
            if (localVarHttpContext === undefined) {
                localVarHttpContext = new i1.HttpContext();
            }
            var responseType_ = 'json';
            if (localVarHttpHeaderAcceptSelected) {
                if (localVarHttpHeaderAcceptSelected.startsWith('text')) {
                    responseType_ = 'text';
                }
                else if (this.configuration.isJsonMime(localVarHttpHeaderAcceptSelected)) {
                    responseType_ = 'json';
                }
                else {
                    responseType_ = 'blob';
                }
            }
            return this.httpClient.delete(this.configuration.basePath + "/user/" + encodeURIComponent(String(id)) + "/subscriptions", {
                context: localVarHttpContext,
                responseType: responseType_,
                withCredentials: this.configuration.withCredentials,
                headers: localVarHeaders,
                observe: observe,
                reportProgress: reportProgress
            });
        };
        UserService.prototype.updateUser = function (updateUserRequest, observe, reportProgress, options) {
            if (observe === void 0) { observe = 'body'; }
            if (reportProgress === void 0) { reportProgress = false; }
            var localVarHeaders = this.defaultHeaders;
            var localVarHttpHeaderAcceptSelected = options && options.httpHeaderAccept;
            if (localVarHttpHeaderAcceptSelected === undefined) {
                // to determine the Accept header
                var httpHeaderAccepts = [
                    'application/json'
                ];
                localVarHttpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
            }
            if (localVarHttpHeaderAcceptSelected !== undefined) {
                localVarHeaders = localVarHeaders.set('Accept', localVarHttpHeaderAcceptSelected);
            }
            var localVarHttpContext = options && options.context;
            if (localVarHttpContext === undefined) {
                localVarHttpContext = new i1.HttpContext();
            }
            // to determine the Content-Type header
            var consumes = [
                'application/json'
            ];
            var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
            if (httpContentTypeSelected !== undefined) {
                localVarHeaders = localVarHeaders.set('Content-Type', httpContentTypeSelected);
            }
            var responseType_ = 'json';
            if (localVarHttpHeaderAcceptSelected) {
                if (localVarHttpHeaderAcceptSelected.startsWith('text')) {
                    responseType_ = 'text';
                }
                else if (this.configuration.isJsonMime(localVarHttpHeaderAcceptSelected)) {
                    responseType_ = 'json';
                }
                else {
                    responseType_ = 'blob';
                }
            }
            return this.httpClient.patch(this.configuration.basePath + "/user", updateUserRequest, {
                context: localVarHttpContext,
                responseType: responseType_,
                withCredentials: this.configuration.withCredentials,
                headers: localVarHeaders,
                observe: observe,
                reportProgress: reportProgress
            });
        };
        return UserService;
    }());
    UserService.ɵprov = i0__namespace.ɵɵdefineInjectable({ factory: function UserService_Factory() { return new UserService(i0__namespace.ɵɵinject(i1__namespace.HttpClient), i0__namespace.ɵɵinject(BASE_PATH, 8), i0__namespace.ɵɵinject(Configuration, 8)); }, token: UserService, providedIn: "root" });
    UserService.decorators = [
        { type: i0.Injectable, args: [{
                    providedIn: 'root'
                },] }
    ];
    UserService.ctorParameters = function () { return [
        { type: i1.HttpClient },
        { type: String, decorators: [{ type: i0.Optional }, { type: i0.Inject, args: [BASE_PATH,] }] },
        { type: Configuration, decorators: [{ type: i0.Optional }] }
    ]; };

    var APIS = [SREService, TeamService, TentativeService, TournamentService, UserService];

    /**
     * clash-bot-webapp-service
     * Clash Bot Webapp Service to support League of Legends Clash tournament scheduling with Discord.
     *
     * The version of the OpenAPI document: 1.1.0
     * Contact: rixxroid@gmail.com
     *
     * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
     * https://openapi-generator.tech
     * Do not edit the class manually.
     */
    var Role = {
        Top: 'Top',
        Mid: 'Mid',
        Jg: 'Jg',
        Bot: 'Bot',
        Supp: 'Supp'
    };

    var ApiModule = /** @class */ (function () {
        function ApiModule(parentModule, http) {
            if (parentModule) {
                throw new Error('ApiModule is already loaded. Import in your base AppModule only.');
            }
            if (!http) {
                throw new Error('You need to import the HttpClientModule in your AppModule! \n' +
                    'See also https://github.com/angular/angular/issues/20575');
            }
        }
        ApiModule.forRoot = function (configurationFactory) {
            return {
                ngModule: ApiModule,
                providers: [{ provide: Configuration, useFactory: configurationFactory }]
            };
        };
        return ApiModule;
    }());
    ApiModule.decorators = [
        { type: i0.NgModule, args: [{
                    imports: [],
                    declarations: [],
                    exports: [],
                    providers: []
                },] }
    ];
    ApiModule.ctorParameters = function () { return [
        { type: ApiModule, decorators: [{ type: i0.Optional }, { type: i0.SkipSelf }] },
        { type: i1.HttpClient, decorators: [{ type: i0.Optional }] }
    ]; };

    /**
     * Generated bundle index. Do not edit.
     */

    exports.APIS = APIS;
    exports.ApiModule = ApiModule;
    exports.BASE_PATH = BASE_PATH;
    exports.COLLECTION_FORMATS = COLLECTION_FORMATS;
    exports.Configuration = Configuration;
    exports.Role = Role;
    exports.SREService = SREService;
    exports.TeamService = TeamService;
    exports.TentativeService = TentativeService;
    exports.TournamentService = TournamentService;
    exports.UserService = UserService;

    Object.defineProperty(exports, '__esModule', { value: true });

}));
//# sourceMappingURL=clash-bot-service-api.umd.js.map
